.. include:: ../README.rst

Contents
========

.. toctree::
    :maxdepth: 2

    README <self>
    api
    examples

.. toctree::
    :maxdepth: 1

    numerical_integration
    bourdet_algorithm
    testing
    versions
    genindex
